Index: drivers/dahdi/dahdi_dynamic_loc.c
===================================================================
--- drivers/dahdi/dahdi_dynamic_loc.c	(revision 5118)
+++ drivers/dahdi/dahdi_dynamic_loc.c	(working copy)
@@ -72,7 +72,7 @@
 	struct ztdlocal *next;
 } *zdevs = NULL;
 
-/*static*/ int ztdlocal_transmit(void *pvt, unsigned char *msg, int msglen)
+static int ztdlocal_transmit(void *pvt, unsigned char *msg, int msglen)
 {
 	struct ztdlocal *z;
 	unsigned long flags;
@@ -121,7 +121,7 @@
 	return -1;
 }
 
-/*static*/ void ztdlocal_destroy(void *pvt)
+static void ztdlocal_destroy(void *pvt)
 {
 	struct ztdlocal *z = pvt;
 	unsigned long flags;
@@ -156,7 +156,7 @@
 	}
 }
 
-/*static*/ void *ztdlocal_create(struct dahdi_span *span, char *address)
+static void *ztdlocal_create(struct dahdi_span *span, char *address)
 {
 	struct ztdlocal *z, *l;
 	unsigned long flags;
@@ -247,13 +247,13 @@
 	NULL	/* flush */
 };
 
-/*static*/ int __init ztdlocal_init(void)
+static int __init ztdlocal_init(void)
 {
 	dahdi_dynamic_register(&ztd_local);
 	return 0;
 }
 
-/*static*/ void __exit ztdlocal_exit(void)
+static void __exit ztdlocal_exit(void)
 {
 	dahdi_dynamic_unregister(&ztd_local);
 }
Index: drivers/dahdi/dahdi_transcode.c
===================================================================
--- drivers/dahdi/dahdi_transcode.c	(revision 5118)
+++ drivers/dahdi/dahdi_transcode.c	(working copy)
@@ -39,7 +39,7 @@
 #include <dahdi/kernel.h>
 
 static int debug;
-LIST_HEAD(trans);
+static LIST_HEAD(trans);
 static spinlock_t translock = SPIN_LOCK_UNLOCKED;
 
 EXPORT_SYMBOL(dahdi_transcoder_register);
@@ -408,16 +408,16 @@
 }
 
 static struct file_operations __dahdi_transcode_fops = {
-	owner:   THIS_MODULE,
-	open:    dahdi_tc_open,
-	release: dahdi_tc_release,
-	ioctl:   dahdi_tc_ioctl,
-	read:    dahdi_tc_read,
-	write:   dahdi_tc_write,
-	poll:    dahdi_tc_poll,
-	mmap:    dahdi_tc_mmap,
+	.owner =   THIS_MODULE,
+	.open =    dahdi_tc_open,
+	.release = dahdi_tc_release,
+	.ioctl =   dahdi_tc_ioctl,
+	.read =    dahdi_tc_read,
+	.write =   dahdi_tc_write,
+	.poll =    dahdi_tc_poll,
+	.mmap =    dahdi_tc_mmap,
 #if HAVE_UNLOCKED_IOCTL
-	unlocked_ioctl: dahdi_tc_unlocked_ioctl,
+	.unlocked_ioctl = dahdi_tc_unlocked_ioctl,
 #endif
 };
 
@@ -426,7 +426,7 @@
 	.minor = 250,
 };
 
-int dahdi_transcode_init(void)
+static int dahdi_transcode_init(void)
 {
 	int res;
 
@@ -444,7 +444,7 @@
 	return 0;
 }
 
-void dahdi_transcode_cleanup(void)
+static void dahdi_transcode_cleanup(void)
 {
 	dahdi_unregister_chardev(&transcode_chardev);
 
Index: drivers/dahdi/dahdi-base.c
===================================================================
--- drivers/dahdi/dahdi-base.c	(revision 5118)
+++ drivers/dahdi/dahdi-base.c	(working copy)
@@ -317,7 +317,7 @@
 	wait_queue_head_t sel;
 };
 
-LIST_HEAD(zaptimers);
+static LIST_HEAD(zaptimers);
 
 #ifdef DEFINE_SPINLOCK
 static DEFINE_SPINLOCK(zaptimerlock);
@@ -384,7 +384,7 @@
 static rwlock_t echocan_list_lock = RW_LOCK_UNLOCKED;
 #endif
 
-LIST_HEAD(echocan_list);
+static LIST_HEAD(echocan_list);
 
 struct echocan {
 	const struct dahdi_echocan *ec;
@@ -7128,7 +7128,7 @@
 		__qevent(ss->master, event);
 }
 
-extern void dahdi_hdlc_abort(struct dahdi_chan *ss, int event)
+void dahdi_hdlc_abort(struct dahdi_chan *ss, int event)
 {
 	unsigned long flags;
 	spin_lock_irqsave(&ss->lock, flags);
@@ -7136,7 +7136,7 @@
 	spin_unlock_irqrestore(&ss->lock, flags);
 }
 
-extern void dahdi_hdlc_putbuf(struct dahdi_chan *ss, unsigned char *rxb, int bytes)
+void dahdi_hdlc_putbuf(struct dahdi_chan *ss, unsigned char *rxb, int bytes)
 {
 	unsigned long flags;
 	int res;
@@ -7171,7 +7171,7 @@
 	spin_unlock_irqrestore(&ss->lock, flags);
 }
 
-extern void dahdi_hdlc_finish(struct dahdi_chan *ss)
+void dahdi_hdlc_finish(struct dahdi_chan *ss)
 {
 	int oldreadbuf;
 	unsigned long flags;
@@ -7217,7 +7217,7 @@
 }
 
 /* Returns 1 if EOF, 0 if data is still in frame, -1 if EOF and no buffers left */
-extern int dahdi_hdlc_getbuf(struct dahdi_chan *ss, unsigned char *bufptr, unsigned int *size)
+int dahdi_hdlc_getbuf(struct dahdi_chan *ss, unsigned char *bufptr, unsigned int *size)
 {
 	unsigned char *buf;
 	unsigned long flags;
Index: drivers/dahdi/dahdi_dynamic.c
===================================================================
--- drivers/dahdi/dahdi_dynamic.c	(revision 5118)
+++ drivers/dahdi/dahdi_dynamic.c	(working copy)
@@ -785,7 +785,7 @@
 	spin_unlock_irqrestore(&dlock, flags);
 }
 
-struct timer_list alarmcheck;
+static struct timer_list alarmcheck;
 
 static void check_for_red_alarm(unsigned long ignored)
 {
@@ -817,7 +817,7 @@
 	
 }
 
-int ztdynamic_init(void)
+static int ztdynamic_init(void)
 {
 	dahdi_set_dynamic_ioctl(ztdynamic_ioctl);
 	/* Start process to check for RED ALARM */
@@ -834,7 +834,7 @@
 	return 0;
 }
 
-void ztdynamic_cleanup(void)
+static void ztdynamic_cleanup(void)
 {
 #ifdef ENABLE_TASKLETS
 	if (taskletpending) {
Index: drivers/dahdi/dahdi_dynamic_eth.c
===================================================================
--- drivers/dahdi/dahdi_dynamic_eth.c	(revision 5118)
+++ drivers/dahdi/dahdi_dynamic_eth.c	(working copy)
@@ -59,7 +59,7 @@
 	struct ztdeth *next;
 } *zdevs = NULL;
 
-struct dahdi_span *ztdeth_getspan(unsigned char *addr, unsigned short subaddr)
+static struct dahdi_span *ztdeth_getspan(unsigned char *addr, unsigned short subaddr)
 {
 	unsigned long flags;
 	struct ztdeth *z;
@@ -207,9 +207,9 @@
 }
 
 static struct packet_type ztdeth_ptype = {
-	type: __constant_htons(ETH_P_DAHDI_DETH),		/* Protocol */
-	dev: NULL,					/* Device (NULL = wildcard) */
-	func: ztdeth_rcv,				/* Receiver */
+	.type = __constant_htons(ETH_P_DAHDI_DETH),		/* Protocol */
+	.dev = NULL,					/* Device (NULL = wildcard) */
+	.func = ztdeth_rcv,				/* Receiver */
 };
 
 static int digit2int(char d)
@@ -409,7 +409,7 @@
 };
 
 static struct notifier_block ztdeth_nblock = {
-	notifier_call: ztdeth_notifier,
+	.notifier_call = ztdeth_notifier,
 };
 
 static int __init ztdeth_init(void)
